@@ -1,5 +1,5 @@
 # RedSSH
-# Copyright (C) 2018 - 2020  Red_M ( http://bitbucket.com/Red_M )
+# Copyright (C) 2018 - 2022 Red_M ( http://bitbucket.com/Red_M )
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,21 +16,28 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 import enum
 
-class SSHHostKeyVerify(enum.Enum):
+class StrEnum(str, enum.Enum):
+    pass
+
+class SSHHostKeyVerify(enum.IntEnum):
     strict = 0
     warn = 1
     warn_auto_add = 2
     auto_add = 3
     none = 4
 
-class TunnelType(enum.Enum):
+class TunnelType(StrEnum):
     local = 'local'
     remote = 'remote'
     dynamic = 'dynamic'
     x11 = 'X11'
 
-class TunnelErrorLevel(enum.Enum):
+class TunnelErrorLevel(enum.IntEnum):
     none = 0
     warn = 1
     error = 2
     debug = 3
+
+class SSHClient(StrEnum):
+    libssh2 = 'LibSSH2'
+    libssh = 'LibSSH'
